@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2023 Jen-Chieh Shen
+ * Copyright (C) 2022-2024 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,15 +12,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNU Emacs; see the file COPYING.  If not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 "use strict";
 
 exports.command = ['lint <type>'];
-exports.desc = 'Run linter';
+exports.desc = 'Run linters';
 exports.builder = function (yargs) {
   yargs.usage(`${exports.desc}
 
