@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2023 Jen-Chieh Shen
+ * Copyright (C) 2022-2024 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,19 +12,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GNU Emacs; see the file COPYING.  If not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 "use strict";
 
-exports.command = ['package [destination]'];
+exports.command = ['package [destination]', 'pack [destination]'];
 exports.desc = 'Build a package artifact, and put it into the given destination';
 exports.builder = yargs => yargs
   .positional(
-    '[destination]', {
+    'destination', {
       description: 'destination path/folder',
+      alias: 'dest',
       type: 'string',
     });
 
