@@ -17,10 +17,11 @@
 ;; Handle options
 (add-hook 'eask-before-command-hook
           (lambda ()
-            (when (= eask-verbosity 4) (setq ert-runner-verbose t))))
+            (when (eask-reach-verbosity-p 'debug)
+              (setq ert-runner-verbose t))))
 
 (eask-start
-  (eask-with-archives "melpa"
+  (eask-with-archives '("gnu" "melpa")
     (eask-package-install 'ert-runner))
   (require 'ert-runner))
 
